//Exercise clock created by Sunyecz Bros 11/2020.
//Main components required include: 4x 15 neopixel ring segments; DS1307 RTC module; Piezo buzzer; Arduino Pro Mini 5v; 1.2" Adafruit 7 Segment Display; iHome iH9 IR sensor; iHome iH9 IR remote
//This clock can perform various functions that include: 1) Real time clock 2) Simple countdown timer 3) Recurrent countdown timer with adjustable break timer in between sets
//The neopixel ring is used as a visual display to highlight current time as well as a timer countdown display

//i2c initialization for 7 segment display/backpack
#include <Wire.h> // Enable this line if using Arduino Uno, Mega, etc.
#include <Adafruit_GFX.h>
#include "Adafruit_LEDBackpack.h"
#include "RTClib.h"

//Neopixel Ring initialization
#include <Adafruit_NeoPixel.h>
#ifdef __AVR__
#include <avr/power.h> // Required for 16 MHz Adafruit Trinket
#endif
#define LED_PIN    6
#define LED_COUNT 60 // How many NeoPixels are attached to the Arduino?
Adafruit_NeoPixel strip(LED_COUNT, LED_PIN, NEO_GRB + NEO_KHZ800);

//IR Sensor initialization
#define IR_SMALLD_NEC        //1st: define which protocol to use and then,
#include <IRsmallDecoder.h>  //2nd: include the library;
IRsmallDecoder irDecoder(2); //3rd: create one decoder object with the correct digital pin;
irSmallD_t irData;           //4th: declare one decoder data structure;

#define TIME_24_HOUR      false
RTC_DS3231 rtc;
Adafruit_7segment clockDisplay = Adafruit_7segment(); //Adafruit 7 Segment will now be called "clockDisplay"
int hours = 0;
int minutes = 0;
int seconds = 0;
bool blinkColon = false; //boolean state for blinking colon on 7 segment
bool blinkLoop = false; //boolean state for lower left decimal in 7 segment
bool hourflag = false; //boolean state to for a new hour when neopixels LED need to be a solid color
bool flip = false; //boolean state to flip neopixel LEDs when counting down from xx:00 --> xx:59....
bool fadeFlip = false; //boolean state to indicate whether LED's are off or fully on within testFade() function
char currentPage;
int Timer = 0;
int Scount = 0; //Seconds in Timer Loop
int Mcount = 0; //Minutes in Timer Loop
int Tcount = 0; //Ten Minutes in Timer Loop
int Sorig; //Original seconds - used when user is in the recurrent timer setting
int Morig; //Original minutes - used when user is in the recurrent timer setting
int Torig; //Original ten minutes - used when user is in the recurrent timer setting
int Ssleep = 0; //Seconds in break timer loop
int SsleepOrig = 0; //Original seconds in break timer loop
int Msleep = 0; //Minutes in break timer loop
int MsleepOrig = 0; //Original minutes in break timer loop
long LEDColor[3]; //Initialize LED color array
const int buzzer = 3;


void setup() {
#if defined(__AVR_ATtiny85__) && (F_CPU == 16000000)
  clock_prescale_set(clock_div_1);
#endif
  strip.begin();           //Initialize NeoPixel strip object (REQUIRED)
  strip.show();            //Turn OFF all pixels ASAP
  strip.setBrightness(10); //Set brightness max of ~50

#ifndef ESP8266
  while (!Serial); // for Leonardo/Micro/Zero
#endif

#ifndef __AVR_ATtiny85__
  //Serial.begin(9600);
  //Serial.println("7 Segment Backpack Test");
#endif
  clockDisplay.begin(0x70);

  if (! rtc.begin()) {
    Serial.println("Couldn't find RTC");
    while (1);
  }

  if (rtc.lostPower()) {
    Serial.println("RTC lost power, lets set the time!");
    // If the RTC have lost power it will sets the RTC to the date & time this sketch was compiled in the following line
    rtc.adjust(DateTime(F(__DATE__), F(__TIME__)));
    // This line sets the RTC with an explicit date & time, for example to set
    // January 21, 2014 at 3am you would call:
    // rtc.adjust(DateTime(2014, 1, 21, 3, 0, 0));
  }
  currentPage = '0';
  setWhite(); //Set pixels to be white
  randomSeed(analogRead(0)); //Random seed for generating neopixel colors
  pinMode(buzzer, OUTPUT); //Initialize buzzer to be an output
}

void loop() {
  //-----------------------------------------Clock Home Page---------------------------------------------
  //Clock setting - 7 segment displays current time; LEDs light up according to minute; IR sensor awaits button press
  if (currentPage == '0') {
    if (minutes == 0) {
      DateTime now = rtc.now(); //Get the time from the DS1307 when a new hour hits.
      hours = now.hour(); //Set hours
      minutes = now.minute(); //Set minutes
    }
    int displayValue = hours * 100 + minutes; //Convert incoming minutes and hours from DS1307 to a displayable unit

    if (hours >= 21 || hours <= 5) {
      strip.clear();
      strip.show();
    }
    else {
      for (int i = 0; i < strip.numPixels(); i++) { //Set number of pixels to be red corresponding to current minutes in the hour
        if (i < minutes && minutes != 0) {
          strip.setPixelColor(i, 255, 0, 0); //For example 3:10 - Set first 10 pixels to red, the rest being white
          hourflag = true;
        }
        if (minutes == 0 && hourflag == true) { //If its a new hour - reset all pixels to white. Only do this once
          strip.clear();
          setWhite();
          hourflag = !hourflag;
        }
      }
      strip.show();
    }

    if (!TIME_24_HOUR) {
      // Handle when hours are past 12 by subtracting 12 hours (1200 value).
      if (hours > 12) {
        displayValue -= 1200;
      }
      // Handle hour 0 (midnight) being shown as 12.
      else if (hours == 0) {
        displayValue += 1200;
      }
    }

    clockDisplay.print(displayValue, DEC); // Now print the time value to the display.

    if (TIME_24_HOUR && hours == 0) { //Add zero padding when in 24 hour mode and it's midnight
      // Pad hour 0.
      clockDisplay.writeDigitNum(1, 0);
      // Also pad when the 10's minute is 0 and should be padded.
      if (minutes < 10) {
        clockDisplay.writeDigitNum(2, 0);
      }
    }

    //Blink the colon by flipping its value every loop iteration (which happens every second)
    blinkColon = !blinkColon;
    clockDisplay.drawColon(blinkColon);

    clockDisplay.writeDisplay(); //Push out to display so time and colon are updated
    delay(1000); //Pause for 1 second

    //Listen for IR button Press - Press "Menu" Button on iHome controller
    if (irDecoder.dataAvailable(irData)) {
    }
    if (irData.cmd == 143) { //"Menu" Button Pressed
      currentPage = '1'; //Send to Timer Setting Page
      beep(); //Add a beep sound for aesthetics
      clockDisplay.clear();
      clockDisplay.writeDisplay();
      colorWipeClear();
      for (int k = 0; k < 3; k++) { //Set random color for neopixels
        LEDColor[k] = random(1, 255);
      }
      flip = false;
      irData.cmd = 0;
    }

    // Now increase the seconds by one.
    seconds += 1;
    // If the seconds go above 59 then the minutes should increase and the seconds should wrap back to 0.
    if (seconds > 59) {
      seconds = 0;
      minutes += 1;
      // Again if the minutes go above 59 then the hour should increase and the minutes should wrap back to 0.
      if (minutes > 59) {
        minutes = 0;
        hours += 1;
        // Note that when the minutes are 0 (i.e. it's the top of a new hour)
        // then the start of the loop will read the actual time from the DS1307
        // again.  Just to be safe though we'll also increment the hour and wrap
        // back to 0 if it goes above 23 (i.e. past midnight).
        if (hours > 23) {
          hours = 0;
        }
      }
    }
  }

  //-----------------------------------------Timer Setting Page------------------------------------
  if (currentPage == '1') {

    //These if statements light up the neopixel corresponding to the number of minutes the user selects
    //E.g. if the user sets a timer for "10:30" - half of the neopixels (the first 30) will be lit up in
    //one color and the other half will be lit up in a different color
    for (int i = 0; i < strip.numPixels(); i++) {
      if (i < Scount && Mcount == 0) { //Timer set to 1 minute or less i.e. ":20 seconds"
        strip.setPixelColor(i, LEDColor[0], LEDColor[1], LEDColor[2]);
      }
      else { //If timer is set to 0
        strip.setPixelColor(i, 0, 0, 0);
      }
      if (Scount != 0 && Mcount != 0) { //Timer set to > 1 minute with some additional seconds i.e. "1:20 seconds"
        if (i < Scount) { //Ensure those seconds are lit up differently than rest of neopixel ring
          strip.setPixelColor(i, LEDColor[0], LEDColor[1], LEDColor[2]);
        }
        else { //Light up rest of neopixel ring
          strip.setPixelColor(i, LEDColor[2], 0, LEDColor[1]);
        }
      }
      if (Scount == 0 && Mcount != 0) { //Timer set to a specific minute with no additional seconds i.e. "1:00 minute"
        strip.setPixelColor(i, LEDColor[0], LEDColor[1], LEDColor[2]);
      }
      if (Scount == 0 && Tcount != 0) { //Timer set to a specific (ten) minute with no additional seconds i.e. "10:00 minutes"
        strip.setPixelColor(i, LEDColor[0], LEDColor[1], LEDColor[2]);
      }
      if (Scount != 0 && Tcount != 0) { //Timer set to a specific (ten) minute with additional seconds i.e. "10:30"
        if (i < Scount) { //Ensure seconds is lit up differently than rest of neopixel ring
          strip.setPixelColor(i, LEDColor[0], LEDColor[1], LEDColor[2]);
        }
        else { //Light up rest of neopixel ring
          strip.setPixelColor(i, LEDColor[2], 0, LEDColor[1]);
        }
      }
    }
    strip.show();

    // Listen to IR sensor for button press input
    if (irDecoder.dataAvailable(irData)) {
    }
    if (irData.cmd == 129) { //"Radio" = add +05 seconds
      irData.cmd = 0;
      beep();
      Scount = Scount + 5; //Increment timer by 05 second intervals
      if (Scount > 55) {
        Scount = 0;
      }
    }

    if (irData.cmd == 133) { //"Presets" = add +1 minute
      irData.cmd = 0;
      beep();
      Mcount = Mcount + 100; //Increment timer by 1 minute intervals
      if (Mcount > 900) {
        Mcount = 0;
      }
    }

    if (irData.cmd == 137) { //"Volume+++" = add +10 minutes
      irData.cmd = 0;
      beep();
      Tcount = Tcount + 1000; //Increment timer by 10 minute intervals
      if (Tcount > 5000) {
        Tcount = 0;
      }
    }

    if (irData.cmd == 140) { //"Snooze" = Reset timer count to 0
      irData.cmd = 0;
      beep();
      Timer = 0;
      Scount = 0; Mcount = 0; Tcount = 0;
      colorWipeClear();
    }

    if (irData.cmd == 136) { //"Loop" = Loop is turned high which will reset timer automatically when timer is started
      irData.cmd = 0;
      beep();
      blinkLoop = !blinkLoop;
    }

    if (irData.cmd == 134) { //"Play Pause" = Start the timer when this is pressed
      irData.cmd = 0;
      currentPage = '2';
      Sorig = Scount; //Save original times incase user has "loop" selected so that timer will reset to these values
      Morig = Mcount;
      Torig = Tcount;
      countdown(); //Begin workout with a 3 second countdown: 3..2..1.. Red..Yellow..Green
      lightStart(Scount, Mcount, Tcount); //Initially light up the Neopixel LEDs corresponding to Timer amount
    }

    if (irData.cmd == 128) { //"Sleep" = Take user to "break timer setting" page where user can change seconds between break timer - Preset = 0 seconds
      irData.cmd = 0;
      beep();
      colorWipeClear();
      currentPage = '3';
    }

    if (irData.cmd == 131) { //"On Off" =  Send the clock back to the home clock page
      currentPage = '0';
      irData.cmd = 0;
      beep();
      DateTime now = rtc.now();
      hours = now.hour();
      minutes = now.minute();
      colorWipeClear();
      setWhite();
    }

    clockDisplay.print(Timer); //Display the updated timer
    if (blinkLoop == true) { //If "Loop" is selected, indicate that by turning on decimal in lower left
      clockDisplay.writeDigitRaw(2, 0x08 | 0x02);
    }
    else {
      clockDisplay.writeDigitRaw(2, 0x02); //Only light up colon in the center
    }
    clockDisplay.writeDisplay();
    Timer = Scount + Mcount + Tcount;

    delay(400); //Delay for a little so the button press only gets counted once. No hard debounce function in this code
  }

  //-----------------------------------------Timer Countdown Page------------------------------------
  if (currentPage == '2') {
    clockDisplay.print(Scount + Mcount + Tcount); //Display updated timer
    if (blinkLoop == true) {
      clockDisplay.writeDigitRaw(2, 0x08 | 0x02);
    }
    else {
      clockDisplay.writeDigitRaw(2, 0x02);
    }
    clockDisplay.writeDisplay();

    delay(1000); //Increment in second intervals
    Scount = Scount - 1; //Decrease seconds by 1
    if (Scount < 0) { //When seconds go to 0, make them 59
      Scount = 59;
      Mcount = Mcount - 100; //When seconds go to 0, decrease minute by 1
      if (Mcount < 0) { //If minute is 0, must mean 10 minute increment has decreased "i.e. 10:00 --> 9:59" or "20:00 --> 19:59"
        Mcount = 900;
        Tcount = Tcount - 1000; //Decrease ten minute counter by 1
      }
    }

    lightCountdown(Scount, Mcount, Tcount); //Light up (or turn off) the neopixel LEDs corresponding to current timer

    //If timer hits 0 and loop IS NOT turned high by user, end the timer and go back to home screen
    if ((Scount + Mcount + Tcount) == 0 && blinkLoop == false) {
      clockDisplay.print(Scount + Mcount + Tcount);
      clockDisplay.writeDigitRaw(2, 0x02);
      clockDisplay.writeDisplay();
      strip.setPixelColor(Scount, 0, 0, 0);
      strip.show();
      tone(buzzer, 500);
      delay(2000);
      noTone(buzzer);
      //      for (int i = 0; i < 6; i++) { //Add 5 second delay between timer ending and going back to home screen
      //        clockDisplay.clear();
      //        clockDisplay.print(5 - i);
      //        clockDisplay.writeDigitRaw(2, 0x02);
      //        clockDisplay.writeDisplay();
      //        testFade();
      //      }
      colorWipeClear(); //Clear LEDs in a sweeping fashion
      fadeFlip = false;
      currentPage = '0'; //Send to Clock Home Page
      irData.cmd = 0;
      Timer = 0;
      DateTime now = rtc.now(); //Collect current time
      hours = now.hour();
      minutes = now.minute();
      setWhite();
    }

    //If timer hits 0 and loop IS turned high by user, countdown from the break timer that the user selected
    if ((Scount + Mcount + Tcount) == 0 && blinkLoop == true) {
      clockDisplay.print(Scount + Mcount + Tcount);
      clockDisplay.writeDigitRaw(2, 0x08 | 0x02);
      clockDisplay.writeDisplay();
      tone(buzzer, 500);
      delay(1000);
      noTone(buzzer);
      for (int i = 2; i < (SsleepOrig + ((MsleepOrig * 0.6) - 1)); i++) { //Ensures that break timer ends with 3 seconds left so that countdown() can begin
        clockDisplay.clear();
        clockDisplay.print((Ssleep + Msleep)); //Orig had ((Ssleep + Msleep) - i)
        clockDisplay.writeDigitRaw(2, 0x02);
        clockDisplay.writeDisplay();
        testFade();
        Ssleep = Ssleep - 1;
        if (Ssleep < 0) { //When seconds go to 0, make them 59
          Ssleep = 59;
          Msleep = Msleep - 100; //When seconds go to 0, decrease minute by 1
          if (Msleep < 0) { //If minute is 0, must mean 10 minute increment has decreased "i.e. 10:00 --> 9:59" or "20:00 --> 19:59"
            break;
          }
        }
      }
      strip.clear();
      strip.show();
      delay(100);
      countdown(); //Let user know workout is about to resume with a 3 second countdown
      fadeFlip = false;
      Ssleep = SsleepOrig;
      Msleep = MsleepOrig;
      Scount = Sorig;
      Mcount = Morig;
      Tcount = Torig;
      for (int k = 0; k < 3; k++) { //There will be a new set of LED colors for the next countdown timer
        LEDColor[k] = random(1, 255);
      }
      lightStart(Scount, Mcount, Tcount); //Initialze neopixel
    }

    //Check to see if user wants to stop timer early and return to clock; NOTE: Will only work during the actual
    //timer countdown. Will not work during the break timer
    if (irDecoder.dataAvailable(irData)) {
    }
    if (irData.cmd == 131) { //On Off Pressed
      currentPage = '0'; //Send back to Clock Home Page
      irData.cmd = 0;
      beep();
      Timer = 0;
      Scount = 0;
      Mcount = 0;
      Tcount = 0;
      DateTime now = rtc.now(); //Get current time
      hours = now.hour();
      minutes = now.minute();
      setWhite();
    }
  }

  //-----------------------------------------Break Timer Setting Page------------------------------------
  //This page allows user to set break time in between auto restart timer - preset break time is 0 seconds
  //E.g. If the user wants to have a 15 second break in between each sets, they would set that here
  if (currentPage == '3') {
    if (irDecoder.dataAvailable(irData)) {
    }
    clockDisplay.print(Ssleep + Msleep);
    clockDisplay.writeDigitRaw(2, 0x04 | 0x02); //Indicates you are in the correct page to set break time
    clockDisplay.writeDisplay();

    //Similar to timer page, this will light up the LEDs on the neopixel corresponding to what the user chooses
    for (int i = 0; i < strip.numPixels(); i++) {
      if (i < Ssleep && Msleep == 0) {
        strip.setPixelColor(i, LEDColor[0], LEDColor[1], LEDColor[2]);
      }
      else {
        strip.setPixelColor(i, 0, 0, 0);
      }
      if (Ssleep != 0 && Msleep != 0) {
        if (i < Ssleep) {
          strip.setPixelColor(i, LEDColor[0], LEDColor[1], LEDColor[2]);
        }
        else {
          strip.setPixelColor(i, LEDColor[2], 0, LEDColor[1]);
        }
      }
      if (Ssleep == 0 && Msleep != 0) {
        strip.setPixelColor(i, LEDColor[0], LEDColor[1], LEDColor[2]);
      }
    }
    strip.show();

    if (irData.cmd == 129) { //"Radio" = add +05 seconds in-between loop timer
      irData.cmd = 0;
      beep();
      Ssleep = Ssleep + 5; //Increment timer by 5 second intervals
      if (Ssleep > 55) {
        irData.cmd = 133;
        Ssleep = 0;
      }
      SsleepOrig = Ssleep;
    }

    if (irData.cmd == 133) { //"Presets" = add +1 minute in-between loop
      irData.cmd = 0;
      beep();
      Msleep = Msleep + 100; //Increment timer by 1 minute intervals
      if (Msleep > 900) {
        Msleep = 100;
      }
      MsleepOrig = Msleep;
    }

    if (irData.cmd == 140) { //"Snooze" = Reset break timer count to 0
      irData.cmd = 0;
      beep();
      Ssleep = 0; Msleep = 0;
      SsleepOrig = 0; MsleepOrig = 0;
      colorWipeClear();
    }

    if (irData.cmd == 143) { //Menu Button Pressed to take back to timer page
      currentPage = '1'; //Send to Timer Setup Page
      irData.cmd = 0;
      beep();
      colorWipeClear();
    }

    if (irData.cmd == 131) { //"On Off" =  Send the clock back to the current time page
      currentPage = '0';
      irData.cmd = 0;
      beep();
      DateTime now = rtc.now();
      hours = now.hour();
      minutes = now.minute();
      colorWipeClear();
      setWhite();
    }
    delay(400);
  }

}

//Add a short beep when buttons on the remote are pressed
void beep() {
  tone(buzzer, 500);
  delay(100);
  noTone(buzzer);
}

//Set all the neopixels to white
void setWhite() {
  for (int i = 0; i < strip.numPixels(); i++) {
    strip.setPixelColor(i, 127, 127, 127);
    strip.show();
    delay(5);
  }
}

//Fade all the LEDs on the neopixel from high - low and from low - high
void testFade () {
  if (fadeFlip == false) {
    for (int j = 0; j < 240 ; j++) {
      for (int i = 0; i < strip.numPixels(); i++) {
        strip.setPixelColor(i, 240 - j, 0, 0);
      }
      strip.show();
      delay(2);
    }
  }
  else {
    for (int j = 0; j < 240 ; j++) {
      for (int i = 0; i < strip.numPixels(); i++) {
        strip.setPixelColor(i, 0 + j, 0, 0);
      }
      strip.show();
      delay(2);
    }
  }
  fadeFlip = !fadeFlip;
}

//Light up the neopixel in a sweeping clockwise fashion
void colorWipe() {
  for (int i = 0; i < strip.numPixels(); i++) {
    strip.setPixelColor(i, LEDColor[0], LEDColor[1], LEDColor[2]);
    strip.show();
    delay(5);
  }
}

//Clear the neopixel in a sweeping counterclockwise fashion
void colorWipeClear() {
  for (int i = strip.numPixels(); i > -1; i--) { // For each pixel in strip...
    strip.setPixelColor(i, 0, 0, 0);         //  Set pixel's color (in RAM)
    strip.show();                          //  Update strip to match
    delay(5);                           //  Pause for a moment
  }
}

//lightCountdown() changes the neopixel LED's while the timer is running. Will flip between 2
//colors and transitions between the two at each minute. lightStart() is used to initialize the colors
//prior to beginning timer while lightCountdown() actively changes the neopixel LEDs during the timer
void lightCountdown(int Scount, int Mcount, int Tcount) {
  int minTally = Mcount / 100;
  int tenTally = Tcount / 100;
  if (minTally == 0 && tenTally == 0) { //Time is less than 1 minute; turn off remaining lights
    for (int i = 0; i < strip.numPixels(); i++) {
      if (i >= Scount) {
        strip.setPixelColor(i, 0, 0, 0); //led's off
      }
    }
  }
  else { //Time is greater than 1 minute; light up other lights
    if (flip == false) {
      for (int i = 0; i < strip.numPixels(); i++) {
        if (i < Scount) {
          strip.setPixelColor(i, LEDColor[0], LEDColor[1], LEDColor[2]);
        }
        else {
          strip.setPixelColor(i, LEDColor[2], 0, LEDColor[1]);
        }
      }
    }
    if (flip == true) {
      for (int i = 0; i < strip.numPixels(); i++) {
        if (i < Scount) {
          strip.setPixelColor(i, LEDColor[2], 0, LEDColor[1]);
        }
        else {
          strip.setPixelColor(i, LEDColor[0], LEDColor[1], LEDColor[2]);
        }
      }
    }
  }
  if (Scount == 0) {
    flip = !flip;
  }
  strip.show();

}

//countdown() adds a 3 second countdown by beeping, displaying 3..2..1.. on the 7 segment
//and changing the neopixel ring from red...yellow...green.
void countdown() {
  clockDisplay.clear();
  clockDisplay.writeDisplay();
  int RYG[4][3] = {{255, 0, 0}, {255, 255, 0}, {0, 255, 0}, {0, 0, 0}};
  for (int j = 0; j < 3; j++) {
    clockDisplay.print(3 - j);
    clockDisplay.writeDigitRaw(2, 0x02);
    clockDisplay.writeDisplay();
    tone(buzzer, 500);
    for (int i = 0; i < strip.numPixels(); i++) {
      strip.setPixelColor(i, RYG[j][0], RYG[j][1], RYG[j][2]);
      strip.show();
      delay(5);
    }
    noTone(buzzer);
    delay(500);
  }
  clockDisplay.print(0);
  clockDisplay.writeDigitRaw(2, 0x02);
  clockDisplay.writeDisplay();
  strip.clear();
  strip.show();
  tone(buzzer, 1000);
  delay(1000);
  noTone(buzzer);
  clockDisplay.clear();
  clockDisplay.writeDisplay();
}

//ligthStart() will initialize the pixels around the clock to the corresponding start time
void lightStart(int Scount, int Mcount, int Tcount) {
  strip.clear();
  strip.show();
  //If the timer is set for over 1 minute and seconds are not zero (i.e. 1:30)
  if (Mcount != 0 && Scount != 0) {
    for (int i = 0; i < strip.numPixels(); i++) {
      if (i < Scount) {
        strip.setPixelColor(i, LEDColor[0], LEDColor[1], LEDColor[2]); //white
      }
      else {
        strip.setPixelColor(i, LEDColor[2], 0, LEDColor[1]); //blue
      }
    }
  }

  //If timer is set for over 1 minute and seconds are zero (i.e. 5:00)
  if (Mcount != 0 && Scount == 0) {
    for (int i = 0; i < strip.numPixels(); i++) {
      strip.setPixelColor(i, LEDColor[0], LEDColor[1], LEDColor[2]); //white
    }
  }

  if (Mcount == 0 && Scount != 0) { //If timer set for less than 1 minute and seconds are not zero (i.e. :45)
    for (int i = 0; i < strip.numPixels(); i++) {
      if (i < Scount) {
        strip.setPixelColor(i, LEDColor[0], LEDColor[1], LEDColor[2]);
      }
    }
  }

  if (Mcount == 0 && Scount == 0 && Tcount != 0) { //If timer is set for 10 minutes or more
    for (int i = 0; i < strip.numPixels(); i++) {
      strip.setPixelColor(i, LEDColor[0], LEDColor[1], LEDColor[2]);
    }
  }
  if (Tcount != 0 && Scount != 0) {
    for (int i = 0; i < strip.numPixels(); i++) {
      if (i < Scount) {
        strip.setPixelColor(i, LEDColor[0], LEDColor[1], LEDColor[2]); //white
      }
      else {
        strip.setPixelColor(i, LEDColor[2], 0, LEDColor[1]); //blue
      }
    }
  }
  strip.show();
}
